<?php
/**************************************************
  Coppermine 1.5.x Plugin - flf histotag
  *************************************************
 For image without geodata, can create/modify geodata in admin mode only
 Based on code from : http://itouchmap.com/latlong.html
 Pierre BASMOREAU
 Date : 28/09/2010
**************************************************/
define('IN_COPPERMINE', true);
require_once ('include/init.inc.php');

$superCage = Inspekt::makeSuperCage();

//Filter PID of picture
if ($superCage->get->keyExists('id')) {
    $pid = $superCage->get->getInt('id');
} elseif ($superCage->post->keyExists('id')) {
    $pid = $superCage->post->getInt('id');
} else {
    cpg_die(ERROR, $lang_errors['param_missing'], __FILE__, __LINE__);
}

/* --------------------------------------------------------------------------
 * FUNCTION DEFINITIONS
 * --------------------------------------------------------------------------*/
function process_geodata()
{
    global $CONFIG, $USER_DATA, $lang_errors, $lang_editpics_php, $superCage, $flf_lang_var;

    //Check if the form token is valid
    if(!checkFormToken()){
        cpg_die(ERROR, $lang_errors['invalid_form_token'], __FILE__, __LINE__);
    }
	//PID picture
    $pid = $superCage->post->getInt('id');
	//********************Latitude
    $latm = abs($superCage->post->getInt('latm')) . "/1";
	$latref = "N"; // By default
	if ($superCage->post->getInt('latm') < 0)
		$latref = "S";
    $latmd = $superCage->post->getInt('latmd') . "/1";
    $latms = cpgSanitizeUserTextInput($superCage->post->getEscaped('latms')) . "/1";
	$lastlatitude = cpgSanitizeUserTextInput($superCage->post->getEscaped('latbox'));
	//Update string for latitude
	$update = "exif_GPS_GPSLatitudeRef = '$latref', exif_GPS_GPSLatitude_1 = '$latm', exif_GPS_GPSLatitude_2 = '$latmd', exif_GPS_GPSLatitude_3 = '$latms', ";
	//********************Longitude
    $lonm = abs($superCage->post->getInt('lonm')) . "/1";
	$lonref = "E"; // By default
	if ($superCage->post->getInt('lonm') < 0)
		$lonref = "W";
    $lonmd = $superCage->post->getInt('lonmd') . "/1";
    $lonms = cpgSanitizeUserTextInput($superCage->post->getEscaped('lonms')) . "/1";
	$lastlongitude = cpgSanitizeUserTextInput($superCage->post->getEscaped('lonbox'));
	//Update string for longitude
	$update .= "exif_GPS_GPSLongitudeRef = '$lonref', exif_GPS_GPSLongitude_1 = '$lonm', exif_GPS_GPSLongitude_2 = '$lonmd', exif_GPS_GPSLongitude_3 = '$lonms'";
	
	//SQL UPDATE geodata
	if ($superCage->post->keyExists('current_latitude') && $superCage->post->keyExists('current_longitude')) {
		$query = "UPDATE {$CONFIG['TABLE_PREFIX']}plugin_flf_histotag set $update WHERE pid='$pid'";
	}
	//SQL INSERT geodata
	else {
		$query = "INSERT INTO {$CONFIG['TABLE_PREFIX']}plugin_flf_histotag SET pid='$pid', $update ";
	}	
    cpg_db_query($query);
	
	//Save lastlatitude in Config File
	$query = "UPDATE {$CONFIG['TABLE_CONFIG']} SET value='$lastlatitude' WHERE name='plugin_flf_histotag_lastlatitude'";
    cpg_db_query($query);
	//Save lastlongitude in Config File
	$query = "UPDATE {$CONFIG['TABLE_CONFIG']} SET value='$lastlongitude' WHERE name='plugin_flf_histotag_lastlongitude'";
    cpg_db_query($query);
}

/* --------------------------------------------------------------------------
 * MAIN CODE
 * --------------------------------------------------------------------------*/

//Default Submit Button to send geodata
$button_submit = "<input type=\"submit\" value=\"{$flf_lang_var['submit_geodata']}\" id=\"apply_geodata\" name=\"apply_geodata\">";

//If geodata sent by form, process !
if ($superCage->post->keyExists('apply_geodata')) {
    process_geodata();
	$message = "<h2><a href=\"#\" onclick=\"self.close();\">".$flf_lang_var['save_geodata']."</a></h2>";
	// Submit button deactivate after process
	$button_submit = "";
}

//Info picture
$result = cpg_db_query("SELECT *, p.title AS title, p.votes AS votes FROM {$CONFIG['TABLE_PICTURES']} AS p INNER JOIN {$CONFIG['TABLE_ALBUMS']} AS a ON a.aid = p.aid WHERE pid = '$pid'");
$CURRENT_PIC = mysql_fetch_assoc($result);
mysql_free_result($result);

//Authorized to modify picture ?
if (!(GALLERY_ADMIN_MODE || $CURRENT_PIC['category'] == FIRST_USER_CAT + USER_ID || ($CONFIG['users_can_edit_pics'] && $CURRENT_PIC['owner_id'] == USER_ID)) || !USER_ID) {
    cpg_die(ERROR, $lang_errors['access_denied'], __FILE__, __LINE__);
}

$thumb_url = get_pic_url($CURRENT_PIC, 'thumb');
$filename = htmlspecialchars($CURRENT_PIC['filename']);
$filepath = htmlspecialchars($CURRENT_PIC['filepath']);


//Initialize last lat/lon from last picture or lat/lon by default
if ($CONFIG['plugin_flf_histotag_lastlatitude'])
	$latitude_base = $CONFIG['plugin_flf_histotag_lastlatitude'];
else
	$latitude_base = 20;

if ($CONFIG['plugin_flf_histotag_lastlongitude'])
	$longitude_base = $CONFIG['plugin_flf_histotag_lastlongitude'];
else
	$longitude_base = -10;


//Geodata for picture (if modify)
if ($superCage->get->keyExists('latitude')) {
	$current_latitude = $superCage->get->getRaw('latitude');
	$latitude_base = $current_latitude;
}
if ($superCage->get->keyExists('longitude')) {
	$current_longitude = $superCage->get->getRaw('longitude');
	$longitude_base = $current_longitude;
}

//API Key de Google Maps
$apikey=$CONFIG['plugin_flf_histotag_apikey'];

//Map Type
$type=$CONFIG["plugin_flf_histotag_mapmode"];
$maptype="";
switch ($type) {
	case 1:
		$maptype='G_SATELLITE_MAP';
		break;
	case 2:
		$maptype='G_NORMAL_MAP';
		break;
	case 3:
		$maptype='G_HYBRID_MAP';
		break;
	case 4:
		$maptype='G_PHYSICAL_MAP';
		break;
	case 5:
		$maptype='G_SATELLITE_3D_MAP';
		break; 		
	default:
		$maptype='G_PHYSICAL_MAP';	
		break;
}

// Token form
list($timestamp, $form_token) = getFormToken();

// Display map
echo <<<EOT

<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<meta http-equiv="content-type" content="text/html; charset=utf-8">
<meta http-equiv="X-UA-Compatible" content="IE=EmulateIE7" >
<title>Latitude and Longitude of a Point</title>
<meta name="description" content="Find the latitude and longitude of a point using Google Maps.">
<meta name="keywords" content="latitude, longitude, google maps, get latitude and longitude">
<script src="http://maps.google.com/maps?file=api&amp;v=2&amp;sensor=false&amp;key={$apikey}" type="text/javascript"></script>

<script type="text/javascript">
function MapTypeControl(opt_opts) {
  this.options = opt_opts || {};
}

MapTypeControl.prototype = new GControl();

MapTypeControl.prototype.initialize = function(map) {
  var container = document.createElement("div");
  var me = this;
  var mapDiv = me.createButton_("Map");
  var satDiv = me.createButton_("Satellite");
  var hybDiv = me.createButton_("Hybrid");
  var phyDiv = me.createButton_("Terrain");
 
  me.assignButtonEvent_(mapDiv, map, G_NORMAL_MAP, [phyDiv, satDiv, hybDiv]);
  me.assignButtonEvent_(phyDiv, map, G_PHYSICAL_MAP, [mapDiv, satDiv, hybDiv]);
  me.assignButtonEvent_(satDiv, map, G_SATELLITE_MAP, [phyDiv, mapDiv, hybDiv]);
  me.assignButtonEvent_(hybDiv, map, G_HYBRID_MAP, [phyDiv, satDiv, mapDiv]);
  GEvent.addListener(map, "maptypechanged", function() {
    if (map.getCurrentMapType() == G_NORMAL_MAP) {
      GEvent.trigger(mapDiv, "click"); 
    } else if (map.getCurrentMapType() == G_PHYSICAL_MAP) {
      GEvent.trigger(phyDiv, "click");
    } else if (map.getCurrentMapType() == G_SATELLITE_MAP) {
      GEvent.trigger(satDiv, "click");
    } else if (map.getCurrentMapType() == G_HYBRID_MAP) {
      GEvent.trigger(hybDiv, "click");
    }
  });

  container.appendChild(mapDiv);
  container.appendChild(satDiv);
  container.appendChild(hybDiv);
  container.appendChild(phyDiv);

  map.getContainer().appendChild(container);

  GEvent.trigger(map, "maptypechanged");
  return container;
}

MapTypeControl.prototype.createButton_ = function(text) {
  var buttonDiv = document.createElement("div");
  this.setButtonStyle_(buttonDiv);
  buttonDiv.style.cssFloat = "left";
  buttonDiv.style.styleFloat = "left";
  var textDiv = document.createElement("div");
  textDiv.appendChild(document.createTextNode(text));
  textDiv.style.width = "6em";
  buttonDiv.appendChild(textDiv);
  return buttonDiv;
}

MapTypeControl.prototype.assignButtonEvent_ = function(div, map, mapType, otherDivs) {
  var me = this;

  GEvent.addDomListener(div, "click", function() {
    for (var i = 0; i < otherDivs.length; i++) {
      me.toggleButton_(otherDivs[i].firstChild, false);
    }
    me.toggleButton_(div.firstChild, true);
    map.setMapType(mapType);
  });
}

MapTypeControl.prototype.toggleButton_ = function(div, boolCheck) {
   div.style.fontWeight = boolCheck ? "bold" : "";
   div.style.border = "1px solid white";
   var shadows = boolCheck ? ["Top", "Left"] : ["Bottom", "Right"];
   for (var j = 0; j < shadows.length; j++) {
     div.style["border" + shadows[j]] = "1px solid #b0b0b0";
  } 
}

MapTypeControl.prototype.getDefaultPosition = function() {
  return new GControlPosition(G_ANCHOR_TOP_RIGHT, new GSize(7, 7));
}

MapTypeControl.prototype.setButtonStyle_ = function(button) {
  button.style.color = "#000000";
  button.style.backgroundColor = "white";
  button.style.font = "small Arial";
  button.style.border = "1px solid black";
  button.style.padding = "0px";
  button.style.margin= "0px";
  button.style.textAlign = "center";
  button.style.fontSize = "10px"; 
  button.style.cursor = "pointer";
}
</script>

<script type="text/javascript">
//<![CDATA[
// Latitude and Longitude math routines are from: http://www.fcc.gov/mb/audio/bickel/DDDMMSS-decimal.html

var map = null;
var geocoder = null;
var latsgn = 1;
var lgsgn = 1;
var zm = 13; 
var marker = null;
var posset = 0;

function xz() {
if (GBrowserIsCompatible()) {
map = new GMap2(document.getElementById("map"));
map.setCenter(new GLatLng({$latitude_base},{$longitude_base}), 13);
map.setMapType({$maptype});
map.addControl(new GLargeMapControl());
map.addControl(new MapTypeControl());
map.addControl(new GScaleControl());
map.enableScrollWheelZoom();
map.disableDoubleClickZoom();
geocoder = new GClientGeocoder();

marker = new GMarker(new GLatLng({$latitude_base},{$longitude_base}), {draggable: true});
map.addOverlay(marker);
var point = marker.getLatLng();
computepos(point);


GEvent.addListener(marker, "dragend", function() {
var point = marker.getLatLng();
posset = 1;
if (zm == 0)
{map.setCenter(point,7); zm = 1;}
else
{map.setCenter(point);}
computepos(point);
});

}}

function computepos (point)
{
	var latA = Math.abs(Math.round(value=point.y * 1000000.));
	var lonA = Math.abs(Math.round(value=point.x * 1000000.));

	if(value=point.y < 0)
	{
		var ls = '-' + Math.floor((latA / 1000000));
	}
	else
	{
		var ls = Math.floor((latA / 1000000));
	}

	var lm = Math.floor(((latA/1000000) - Math.floor(latA/1000000)) * 60);
	var ld = ( Math.floor(((((latA/1000000) - Math.floor(latA/1000000)) * 60) - Math.floor(((latA/1000000) - Math.floor(latA/1000000)) * 60)) * 100000) *60/100000 );

	if(value=point.x < 0)
	{
	  var lgs = '-' + Math.floor((lonA / 1000000));
	}
	else
	{
		var lgs = Math.floor((lonA / 1000000));
	}

	var lgm = Math.floor(((lonA/1000000) - Math.floor(lonA/1000000)) * 60);
	var lgd = ( Math.floor(((((lonA/1000000) - Math.floor(lonA/1000000)) * 60) - Math.floor(((lonA/1000000) - Math.floor(lonA/1000000)) * 60)) * 100000) *60/100000 );

	document.getElementById("latbox").value=point.y;
	document.getElementById("lonbox").value=point.x;
	document.getElementById("latboxm").value=ls;
	document.getElementById("latboxmd").value=lm;
	document.getElementById("latboxms").value=ld;
	document.getElementById("lonboxm").value=lgs;
	document.getElementById("lonboxmd").value=lgm;
	document.getElementById("lonboxms").value=lgd;
}

function reset1() {
marker.setPoint(map.getCenter());
}

//]]>
</script>

</head>
<body onload="xz()" onunload="GUnload()">
	<div id="map" style="width: 700px; height: 400px"></div>
	<div style="float:left;"><img src="$thumb_url" class="image" border="0" alt="{$CURRENT_PIC['title']}"/></div>
	<div style="float:right;">
	<input type="button" value="{$flf_lang_var['center_marker']}" id="reset1" onclick="reset1()">
    <form name="creategeodata" id="cpgform_creategeodata" method="post" action="index.php?file=flf_histotag/creategeodata">
	{$button_submit}
	
	<input type="hidden" name="form_token" value="{$form_token}" />
	<input type="hidden" name="timestamp" value="{$timestamp}" />
	<input type="hidden" name="id" value="{$CURRENT_PIC['pid']}" />
	
	<input type="hidden" id="latboxm" name="latm" value="" >
	<input type="hidden" id="latboxmd" name="latmd" value="" >
	<input type="hidden" id="latboxms" name="latms" value="" >
	<input type="hidden" id="latbox" name="latbox" value="" >
	
	<input type="hidden" id="lonboxm" name="lonm" value="" >
	<input type="hidden" id="lonboxmd" name="lonmd" value="" >
	<input type="hidden" id="lonboxms" name="lonms" value="" >
	<input type="hidden" id="lonbox" name="lonbox" value="" >

	<input type="hidden" name="current_latitude" value="{$current_latitude}" >
	<input type="hidden" name="current_longitude" value="{$current_longitude}" >
	
	</div>
	</form>
	
	{$message}
	
</body>
</html>

EOT;

?>